Learn R Programming

bipl5 (version 1.0.2)

predict.bipl5: Method to obtain the predicted or fitted values of the biplot

Description

Extract the fitted values of the biplot display

Usage

# S3 method for bipl5
predict(object, ...)

Value

The function invisibly returns the predicted values of the biplot display, and outputs the predicted values via the kable function

Arguments

object

An object of class bipl5 from which predicted values are to be obtained

...

Additional arguments to be passes to the kable function, contained in a list named kable.args

Examples

Run this code
kable.args<-list()
kable.args$format<-"pipe"
x<-PCAbiplot(iris[,-5])
predict(x,kable.args)

Run the code above in your browser using DataLab