powered by
Extract the fitted values of the biplot display
# S3 method for bipl5 predict(object, ...)
The function invisibly returns the predicted values of the biplot display, and outputs the predicted values via the kable function
kable
An object of class bipl5 from which predicted values are to be obtained
bipl5
Additional arguments to be passes to the kable function, contained in a list named kable.args
kable.args<-list() kable.args$format<-"pipe" x<-PCAbiplot(iris[,-5]) predict(x,kable.args)
Run the code above in your browser using DataLab